迭代版的快速排序,不是递归的,速度并不会快多少
投稿作者:千战
围观人数:452
所属栏目:易语言源码
写完了 迭代版快速排序,用一个主要参数一样尺寸的游标数组(纪录上下的起止点终点站),存储了原先的栈
13|56 78|10,11
比如第一组,被四分切割成2个,上下是1 3, 第二个是 5 ,6
随后用第一组数组,测算得到第二组游标数组。下次第二游标组数组测算的結果再遮盖到第一个游标数组。更替应用,比第二个数组立即取值到第一个数组会快一倍了。
基础和递归的快排速率上没区别了。便是室内空间占有大些(栈换为了2组的数组)
結果快排的这一迭代版,還是沒有归并排序的迭代版快
.版本 2
' * “5 秒 398 ms ” 500w
' * 真 | “取得成功=真” | “合并最优控制版本”
' * “8 秒 3 ms ”
' * 真 | “取得成功=真” | “迭代_快排”
' * “11 秒 92 ms ”1000w
' * 真 | “取得成功=真” | “合并最优控制版本”
' * “25 秒 647 ms ”
' * 真 | “取得成功=真” | “迭代_快排********************* 文中的速率在这儿”
' * “26 秒 723 ms ”
' * 真 | “取得成功=真” | “快排初始”
' * “27 秒 425 ms ”
' * 真 | “取得成功=真” | “QuickSort”
引入控制模块
| 源代码文件夹名称 | 控制模块文件夹名称 | |
|---|---|---|
| 迭代版快速排序.e |
|
引入支持库
| 源代码文件夹名称 | 支持库文件夹名称 | 支持库标志 |
|---|---|---|
| 6.8.e | 系统核心支持库 5.7 | d09f2340818511d396f6aaf844c7e325 |
| 运用插口支持库 3.1 | F7FC1AE45C5C4758AF03EF19F18A395D | |
| 独特作用支持库 3.1 | A512548E76954B6E92C21055517615B0 | |
| 迭代版快速排序.e | 系统核心支持库 5.7 | d09f2340818511d396f6aaf844c7e325 |
| 独特作用支持库 3.1 | A512548E76954B6E92C21055517615B0 |
the end
免责声明:本文发布在易语言源码频道,为本站整理编辑,但不代表本站的观点和立场。
站内搜索
最新易语言源码
-
易语言android无障碍千战 2020-09-16 -
利用易语言组件自制快捷启动千战 2020-09-16 -
易语言希尔排序之自定义数据类型排序千战 2020-09-16 -
填充前后文本到指定长度千战 2020-09-15 -
实例_Wininet 置代理地址(立即生效无需重启)千战 2020-09-15 -
超级列表框设置颜色(不闪烁版本)删除表项记得处理颜色数组+置行高千战 2020-09-15 -
小白盒 扫码枪 二维码扫描设备 键盘钩子源码千战 2020-09-15 -
WOL远程开机千战 2020-09-14 -
熊出没之拼图游戏千战 2020-09-14 -
Ylink(纯UI)千战 2020-09-14
推荐易语言源码


